@@ -15,7 +15,8 @@ sub parse_cgi_output {
         open my $io, "<", $output;
         $output = $io;
     } else {
-        binmode $output, ":raw";
+        open my $tmp, '<&=:perlio:raw', fileno($output) or die $!;
+        $output = $tmp;
         $length = -s $output;
     }
 
@@ -33,11 +34,17 @@ sub parse_cgi_output {
     }
 
     my $response = HTTP::Response->parse($headers);
-    $response->date( time() ) unless $response->date;
+
+    # RFC 3875 6.2.3
+    if ($response->header('Location') && !$response->header('Status')) {
+        $response->header('Status', 302);
+    }
 
     my $status = $response->header('Status') || 200;
     $status =~ s/\s+.*$//; # remove ' OK' in '200 OK'
 
+    $response->remove_header('Status'); # PSGI doesn't allow having Status header in the response
+
     my $remaining = $length - tell( $output );
     if ( $response->code == 500 && !$remaining ) {
         return [
@@ -66,13 +73,19 @@ sub parse_cgi_output {
         +[
             map {
                 my $k = $_;
-                map { ( $k => $_ ) } $response->headers->header($_);
+                map { ( $k => _cleanup_newline($_) ) } $response->headers->header($_);
             } $response->headers->header_field_names
         ],
         [$response->content],
     ];
 }
 
+sub _cleanup_newline {
+    local $_ = shift;
+    s/\r?\n//g;
+    return $_;
+}
+
 1;
 
 __END__
